package com.fs.his.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.fs.his.domain.FsIntegralOrderLogs;

import java.util.List;

/**
 * 订单操作记录Service接口
 *
 * @author fs
 * @date 2025-11-25
 */
public interface IFsIntegralOrderLogsService extends IService<FsIntegralOrderLogs> {
    /**
     * 查询订单操作记录
     *
     * @param logsId 订单操作记录主键
     * @return 订单操作记录
     */
    FsIntegralOrderLogs selectFsIntegralOrderLogsByLogsId(String logsId);

    /**
     * 查询订单操作记录列表
     *
     * @param fsIntegralOrderLogs 订单操作记录
     * @return 订单操作记录集合
     */
    List<FsIntegralOrderLogs> selectFsIntegralOrderLogsList(FsIntegralOrderLogs fsIntegralOrderLogs);

    /**
     * 新增订单操作记录
     *
     * @param fsIntegralOrderLogs 订单操作记录
     * @return 结果
     */
    int insertFsIntegralOrderLogs(FsIntegralOrderLogs fsIntegralOrderLogs);

    /**
     * 修改订单操作记录
     *
     * @param fsIntegralOrderLogs 订单操作记录
     * @return 结果
     */
    int updateFsIntegralOrderLogs(FsIntegralOrderLogs fsIntegralOrderLogs);

    /**
     * 批量删除订单操作记录
     *
     * @param logsIds 需要删除的订单操作记录主键集合
     * @return 结果
     */
    int deleteFsIntegralOrderLogsByLogsIds(String[] logsIds);

    /**
     * 删除订单操作记录信息
     *
     * @param logsId 订单操作记录主键
     * @return 结果
     */
    int deleteFsIntegralOrderLogsByLogsId(String logsId);
}
